<?php

namespace Litecms\Memo\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Memo\Actions\MemoAction;
use Litecms\Memo\Http\Requests\MemoActionRequest;
use Litecms\Memo\Http\Resources\MemoResource;
use Litecms\Memo\Models\Memo;

/**
 * Admin web controller class.
 */
class MemoActionController extends BaseController
{

    /**
     * Action controller function for memo.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(MemoActionRequest $request, Memo $memo, $action)
    {
        try {
            $request = $request->all();
            $memo = MemoAction::run($action, $memo, $request);

            $data = new MemoResource($memo);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('memo::memo.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('memo/memo/' . $memo->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('memo/memo/' . $memo->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
