<?php

namespace Litecms\Memo\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Memo\Http\Requests\MemoActionsRequest;
use Litecms\Memo\Actions\MemoActions;

/**
 * Admin web controller class.
 */
class MemoActionsController extends BaseController
{

    /**
     * Action controller function for memo.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(MemoActionsRequest $request, $action)
    {
        try {
            $memo = MemoActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('memo::memo.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('memo/memo/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('memo/memo/' . $action))
                ->redirect();
        }
    }
}
