<?php

namespace Litecms\Memo\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Memo\Http\Resources\MemoResource;
use Litecms\Memo\Http\Resources\MemosCollection;
use Litecms\Memo\Scopes\MemoPublicScope;
use Litecms\Memo\Models\Memo;

class MemoPublicController extends BaseController
{

    /**
     * Show memo's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Memo::pushScope(new RequestScope())
            ->pushScope(new MemoPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $memos = new MemosCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('memo::memo.names'))
            ->view('memo::public.memo.index')
            ->data(compact('memos', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show memo.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Memo::findBySlug($slug);
        $data = new MemoResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('memo::memo.name'))
            ->view('memo::public.memo.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
