<?php

namespace Litecms\Memo\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Memo\Actions\MemoReport;
use Litecms\Memo\Http\Requests\MemoReportRequest;

/**
 * Admin web controller class.
 */
class MemoReportController extends BaseController
{
    /**
     * Action controller function for memo.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(MemoReportRequest $request, $report)
    {
        try {
        
            $this->model = app(Memo::class);
            $data = MemoReport::run($request, $report);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('memo::memo.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('memo/memo/' . $report))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('memo/memo/' . $report))
                ->redirect();
        }
    }
}
