<?php

namespace Litecms\Memo\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Memo\Events\MemoAction as MemoActionEvent;
use Litecms\Memo\Notifications\MemoAction as MemoActionNotification;
use Litepie\Actions\Concerns\AsAction;

class MemoAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the MemoActionEvent.
     *
     * @param   MemoActionEvent  $event
     * @return mixed
     */
    public function handle(MemoActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $memo.
     *
     * @param   MemoActionEvent  $event
     * @return void
     */
    public function create(MemoActionEvent $event)
    {
        $client = $event->memo->client;
        Notification::send($client, new MemoActionNotification($event));
    }

    /**
     * Handle the MemoActionEvent as a listener.
     *
     * @param   MemoActionEvent  $event
     * @return mixed
     */
    public function asListener(MemoActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   MemoActionEvent  $event
     * @return bool
     */
    private function isAllowed(MemoActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
