<?php

namespace Litecms\Memo\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Memo\Events\MemoWorkflow as MemoWorkflowEvent;
use Litecms\Memo\Notifications\MemoWorkflow as MemoWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class MemoWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(MemoWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $memo is submitted.
     *
     * @param MemoWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(MemoWorkflowEvent $event)
    {
        $client = $event->memo->client;
        Notification::send($client, new MemoWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $memo is published.
     *
     * @param MemoWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(MemoWorkflowEvent $event)
    {
        $client = $event->memo->client;
        Notification::send($client, new MemoWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $memo is approved.
     *
     * @param MemoWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(MemoWorkflowEvent $event)
    {
        $client = $event->memo->client;
        Notification::send($client, new MemoWorkflowNotification($event));
    }

    /**
     * Handles the $memo workflow event as a listener.
     *
     * @param MemoWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(MemoWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
