<?php
namespace Litecms\Memo\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Memo\Events\MemoAction as MemoActionEvent;
use Litecms\Memo\Models\Memo;

class MemoAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $memo;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param MemoActionEvent $memo
     */
    public function __construct(MemoActionEvent $memo)
    {
        $this->action = $event->action;
        $this->memo = $memo;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Memo Approved - ' . config('app.name'))
            ->view('memo::memo.email.action', ['data' => $this->memo]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
