<?php

namespace Litecms\Memo\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Memo\Models\Memo;

class MemoPolicy
{

    use MemoAction;
    use MemoReport;
    use MemoWorkflow;

    /**
     * Determine if the given user can view the memo.
     *
     * @param UserPolicyInterface $authUser
     * @param Memo $memo
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Memo $memo)
    {
        if ($authUser->canDo('memo.memo.view') && $authUser->isAdmin()) {
            return true;
        }

        return $memo->user_id == user_id() && $memo->user_type == user_type();
    }

    /**
     * Determine if the given user can create a memo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('memo.memo.create');
    }

    /**
     * Determine if the given user can update the given memo.
     *
     * @param UserPolicyInterface $authUser
     * @param Memo $memo
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Memo $memo)
    {
        if ($authUser->canDo('memo.memo.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $memo->user_id == user_id() && $memo->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given memo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Memo $memo)
    {
        return $memo->user_id == user_id() && $memo->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given memo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Memo $memo)
    {
        if ($authUser->canDo('memo.memo.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given memo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Memo $memo)
    {
        if ($authUser->canDo('memo.memo.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
