<?php

namespace Litecms\Memo\Policies;

use Litecms\Memo\Models\Memo;
use Litepie\User\Interfaces\UserPolicyInterface;

trait MemoWorkflow
{

    /**
     * Determine if the given user can approve the given memo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Memo $memo)
    {
        if ($authUser->canDo('memo.memo.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given memo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function submit(UserPolicyInterface $authUser, Memo $memo)
    {
        if ($authUser->canDo('memo.memo.submit')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given memo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function publish(UserPolicyInterface $authUser, Memo $memo)
    {
        if ($authUser->canDo('memo.memo.publish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given memo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function unpublish(UserPolicyInterface $authUser, Memo $memo)
    {
        if ($authUser->canDo('memo.memo.unpublish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given memo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function archive(UserPolicyInterface $authUser, Memo $memo)
    {
        if ($authUser->canDo('memo.memo.archive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given memo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function unarchive(UserPolicyInterface $authUser, Memo $memo)
    {
        if ($authUser->canDo('memo.memo.unarchive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given memo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function reject(UserPolicyInterface $authUser, Memo $memo)
    {
        if ($authUser->canDo('memo.memo.reject')) {
            return true;
        }

        return false;
    }

}
